@@ -123,7 +123,7 @@ QString BackgroundDlg::returnBackgroundImagePath()
 
 void BackgroundDlg::on_imageButton_clicked()
 {
-    QString fileName = QFileDialog::getOpenFileName(this, tr("Open Image"), "/home/user/MyDocs/qtirreco/themes/", tr("Image Files (*.png *.jpg *.bmp)"));
+    QString fileName = QFileDialog::getOpenFileName(this, tr("Open Image"), themesPath, tr("Image Files (*.png *.jpg *.bmp *.jpeg)"));
     QTextStream inputStream(&fileName);
     QString bgImagePath;
     while (!inputStream.atEnd()) {
@@ -194,10 +194,6 @@ void BackgroundDlg::loadThemes()
                 m_ui->listWidget->show();
             }
         }
-       /* else {
-                themeDirList.removeAt(i);
-                i--;
-             }*/
     }
 }
 void BackgroundDlg::setBackgroundsOnListWidget2()
