@@ -32,7 +32,7 @@ void ButtonSelectDlg::changeEvent(QEvent *e)
 void ButtonSelectDlg::loadThemes()
 {
     themeDirList.clear();
-    QDir *themeDirs = new QDir(DEVICETHEMES);
+    QDir *themeDirs = new QDir(themesPath);
 
     themeDirList = themeDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     themeDirList.insert(0,"default");
@@ -44,7 +44,7 @@ void ButtonSelectDlg::loadThemes()
         if(themeDirList.at(i) == "default")
             themeConf = "/home/user/.qtirreco/themes/default/theme.conf";
 
-        else  themeConf = DEVICETHEMES + themeDirList.at(i) + "/theme.conf";
+        else  themeConf = themesPath + themeDirList.at(i) + "/theme.conf";
 
         QFile file(themeConf);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -73,6 +73,7 @@ void ButtonSelectDlg::loadThemes()
 
 void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
 {
+    m_ui->selectPushButton->setDisabled(true);
     buttonDirList.clear();
     m_ui->label->clear();
     themeIndex = m_ui->HWlistWidget->currentRow();
@@ -80,12 +81,12 @@ void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
     m_ui->HWbuttonListWidget->clear();
 
     if(item->text() == "Default") {
-        QDir *currentThemeDir = new QDir("/home/user/.qtirreco/themes/default/buttons/");
+        QDir *currentThemeDir = new QDir(defaultButtonsPath);
         buttonDirList = currentThemeDir->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
         defaultflag = true;
     }
     else {
-        QDir *currentThemeDir = new QDir(DEVICETHEMES + themeDirList.at(themeIndex) +"/buttons/");
+        QDir *currentThemeDir = new QDir(themesPath + themeDirList.at(themeIndex) +"/buttons/");
         buttonDirList = currentThemeDir->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
         defaultflag = false;
     }
@@ -95,9 +96,9 @@ void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
         QString buttonConf;
 
         if(defaultflag)
-            buttonConf = "/home/user/.qtirreco/themes/default/buttons/" + buttonDirList.at(i) + "/button.conf";
+            buttonConf = defaultButtonsPath + buttonDirList.at(i) + "/button.conf";
 
-        else buttonConf = DEVICETHEMES + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(i) + "/button.conf";
+        else buttonConf = themesPath + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(i) + "/button.conf";
 
         QFile file(buttonConf);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -113,12 +114,12 @@ void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
         }
         file.close();
         if(defaultflag) {
-            QIcon icon("/home/user/.qtirreco/themes/default/buttons/" + buttonDirList.at(i) + "/" + upButtonName);
+            QIcon icon(defaultButtonsPath + buttonDirList.at(i) + "/" + upButtonName);
             item->setIcon(icon);
             item->setText(buttonName);
         }
         else {
-            QIcon icon(DEVICETHEMES + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(i) + "/" + upButtonName);
+            QIcon icon(themesPath + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(i) + "/" + upButtonName);
             item->setIcon(icon);
             item->setText(buttonName);
         }
@@ -131,15 +132,16 @@ void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
 
 void ButtonSelectDlg::setButton()
 {
+    m_ui->selectPushButton->setEnabled(true);
     buttonIndex = m_ui->HWbuttonListWidget->currentRow();
     if(defaultflag) {
-        QPixmap pix("/home/user/.qtirreco/themes/default/buttons/" + buttonDirList.at(buttonIndex) + "/" + upButtonName);
+        QPixmap pix(defaultButtonsPath + buttonDirList.at(buttonIndex) + "/" + upButtonName);
         m_ui->label->setPixmap(pix.scaled(128,128,Qt::KeepAspectRatio,Qt::FastTransformation));
         m_ui->label->setAlignment(Qt::AlignCenter);
         m_ui->selectPushButton->setEnabled(true);
     }
     else {
-        QPixmap pix(DEVICETHEMES + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/" + upButtonName);
+        QPixmap pix(themesPath + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/" + upButtonName);
         m_ui->label->setPixmap(pix.scaled(128,128,Qt::KeepAspectRatio,Qt::FastTransformation));
         m_ui->label->setAlignment(Qt::AlignCenter);
         m_ui->selectPushButton->setEnabled(true);
@@ -153,15 +155,15 @@ void ButtonSelectDlg::on_selectPushButton_clicked()
     QString confFileName;
 
     if(defaultflag) {
-        fileNameUnPressed = ("/home/user/.qtirreco/themes/default/buttons/" + buttonDirList.at(buttonIndex) + "/" + upButtonName);
-        fileNamePressed = ("/home/user/.qtirreco/themes/default/buttons/" + buttonDirList.at(buttonIndex) + "/" + downButtonName);
-        confFileName = ("/home/user/.qtirreco/themes/default/buttons/" + buttonDirList.at(buttonIndex) + "/button.conf");
+        fileNameUnPressed = (defaultButtonsPath + buttonDirList.at(buttonIndex) + "/" + upButtonName);
+        fileNamePressed = (defaultButtonsPath + buttonDirList.at(buttonIndex) + "/" + downButtonName);
+        confFileName = (defaultButtonsPath + buttonDirList.at(buttonIndex) + "/button.conf");
     }
     else if(!defaultflag)
     {
-        fileNameUnPressed = (DEVICETHEMES + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/" + upButtonName);
-        fileNamePressed = (DEVICETHEMES + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/" + downButtonName);
-        confFileName = (DEVICETHEMES + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/button.conf");
+        fileNameUnPressed = (themesPath + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/" + upButtonName);
+        fileNamePressed = (themesPath + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/" + downButtonName);
+        confFileName = (themesPath + themeDirList.at(themeIndex) + "/buttons/" + buttonDirList.at(buttonIndex) + "/button.conf");
     }
     emit signalAddButton(fileNameUnPressed, fileNamePressed, confFileName);
     this->close();
