@@ -18,7 +18,7 @@ ButtonWidget::ButtonWidget(QWidget *parent, const QString aFilenameUnpressed,con
         textUpColor = new QColor(255,255,255);
         textDownColor = new QColor(255,255,255);
 
-        if(fileNameUnPressed.contains("/home/user/MyDocs/qtirreco/themes/",Qt::CaseInsensitive)) {
+        if(fileNameUnPressed.contains(themesPath,Qt::CaseInsensitive)) {
             fileNameUnPressed = aFilenameUnpressed;
             fileNamePressed = aFileNamePressed;
             confFileName = aConfFileName;
@@ -27,9 +27,13 @@ ButtonWidget::ButtonWidget(QWidget *parent, const QString aFilenameUnpressed,con
 
         QFile file(confFileName);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-            QMessageBox::warning(this,"Error with button config","Failed to load button config",
+            QMessageBox::warning(this,"Error with button config","Failed to load button config. Using default button instead.",
                      QMessageBox::NoButton,QMessageBox::NoButton);
-            return;
+
+            fileNameUnPressed = defaultButtonsPath + "blank/unpressed.png";
+            fileNamePressed = defaultButtonsPath + "blank/pressed.png";
+            confFileName = defaultButtonsPath + "blank/button.conf";
+            QFile file(confFileName);
         }
 
         QTextStream in(&file);
