@@ -6,8 +6,7 @@
 #include <QDir>
 
 #include "newbuttondlg.h"
-
-#define DEVICE "/home/user/MyDocs/qtirreco/Devices/"
+#include "definitions.h"
 
 namespace Ui {
     class CommandChainDlg;
