@@ -86,7 +86,7 @@ void CreateBackgroundDlg::on_addPushButton_clicked()
 }
 void CreateBackgroundDlg::on_selectPushButton_clicked()
 {
-    fileName = QFileDialog::getOpenFileName(this, tr("Open Image"), "/home/user/MyDocs/qtirreco/themes/", tr("Image Files (*.png)"));
+    fileName = QFileDialog::getOpenFileName(this, tr("Open Image"), themesPath, tr("Image Files (*.png)"));
     QPixmap pix(fileName);
     if(!pix.isNull()) {
         if(m_ui->lineEdit->text() != "" )
