@@ -9,7 +9,7 @@ const QString qtirrecoImage = "/home/user/.qtirreco/themes/default/bg/qtirreco/i
 const QString devicesPath = "/home/user/MyDocs/qtirreco/Devices/";
 const QString remotesConf = "/home/user/MyDocs/qtirreco/Remotes/remotes.conf";
 const QString lircpathsConf = "/home/user/MyDocs/qtirreco/lirchpaths.conf";
-const QString themesPath = "/home/user/MyDocs/qtirreco/themes/";
+const QString themesPath = "/home/user/MyDocs/qtirreco/.themes/";
 const QString defaultButtonsPath = "/home/user/.qtirreco/themes/default/buttons/";
 
 
