@@ -89,14 +89,18 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
     }
     if (Id == fileId) {
         QDir dir;
-        if(!dir.exists("/home/user/MyDocs/qtirreco/Devices"))
-            dir.mkpath(DEVICES);
-        if(!QFile::exists(DEVICES + modelItem)) {
-            QFile deviceFile(DEVICES + modelItem);
+        if(!dir.exists(devicesPath))
+            dir.mkpath(devicesPath);
+        if(!QFile::exists(devicesPath + modelItem)) {
+            QFile deviceFile(devicesPath + modelItem);
             deviceFile.open(QIODevice::WriteOnly | QIODevice::Text);
             QTextStream out(&deviceFile);
-            for(int i= 0; i< sList.count();i++) {
-                out << sList.at(i);
+            for(int i= 0; i< sList.count();i++) { // Streams only one remote data to file
+                QString line = sList.at(i);
+                out << sList.at(i); // Original line
+                if(line.contains("end remote",Qt::CaseInsensitive))
+                    break;
+
             }
 
             deviceFile.close();
@@ -135,7 +139,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
                 remotestartupdlg->exec();
                 delete remotestartupdlg;
             }
-            QFile lircPathsFile("/home/user/MyDocs/qtirreco/lircpaths.conf");
+            QFile lircPathsFile(lircpathsConf);
             lircPathsFile.open(QIODevice::ReadWrite | QIODevice::Append);
             QTextStream stream(&lircPathsFile);
             bool lircExists = false;
