@@ -27,8 +27,6 @@ DownloadUserRemoteDlg::DownloadUserRemoteDlg(QWidget *parent) :
     params.clear();
     listId = client->call("getRemoteCategories",params);
 
-
-
 }
 
 DownloadUserRemoteDlg::~DownloadUserRemoteDlg()
@@ -83,7 +81,7 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
         QVariant dataVar = array.value("data");
         QString data = dataVar.toString();
 
-        QFile file("/home/user/MyDocs/qtirreco/Remotes/"+ fileName);
+        QFile file(remotesPath + fileName);
         if (file.exists()) {
             replaceRemote = false;
              /*QMessageBox::warning(this,"Remote name already exists!","Cannot download remote, please delete remote with same name before downloading.",
