@@ -7,11 +7,10 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, QVector<ButtonWidget*> *vector) :
     QDialog(parent),
     m_ui(new Ui::NewButtonDlg)
 {
+    m_ui->setupUi(this);
     buttonTextToEmit.clear();
     editMode = false;
-    buttons = new QVector<ButtonWidget*>;
     buttons = vector;
-    m_ui->setupUi(this);
     connect(m_ui->horizontalScrollBar,SIGNAL(valueChanged(int)),this,SLOT(setTimeOut(int)));
     m_ui->styleChangePushButton->show();
     m_ui->OkPushButton->setDisabled(true);
@@ -24,22 +23,19 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonW
     QDialog(parent),
     m_ui(new Ui::NewButtonDlg)
 {
+    m_ui->setupUi(this);
     buttonTextToEmit.clear();
     editMode = true;
-    buttons = new QVector<ButtonWidget*>;
     buttons = vector;
     button = child;
-    m_ui->setupUi(this);
     connect(m_ui->horizontalScrollBar,SIGNAL(valueChanged(int)),this,SLOT(setTimeOut(int)));
     m_ui->horizontalScrollBar->hide();
     m_ui->timeOutLabel->hide();
     m_ui->timeOutValueLabel->hide();
     this->addPreviewImage(child->fileNameUnPressed,child->fileNamePressed,child->confFileName);
     m_ui->nameLineEdit->setText(QString(child->buttonText));
-    int commandCount = child->commandChain.size();
-    for(int i= 0;i<commandCount;i++)
+    for(int i= 0;i<child->commandChain.size();i++)
         m_ui->commandChainList->insertItem(i,child->commandChain.at(i));
-
     if(child->commandChain.count() > 1) {
          m_ui->horizontalScrollBar->show();
          m_ui->timeOutLabel->show();
@@ -49,7 +45,6 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonW
          str.setNum(child->timeOut);
          m_ui->timeOutValueLabel->setText(str+"ms");
     }
-
 }
 
 NewButtonDlg::~NewButtonDlg()
@@ -71,8 +66,7 @@ void NewButtonDlg::changeEvent(QEvent *e)
 void NewButtonDlg::on_OkPushButton_clicked()
 {
     bool buttonNameExists = false;
-    int val = m_ui->horizontalScrollBar->value();
-    timeOut = val*100;
+    timeOut = m_ui->horizontalScrollBar->value()*100;
     if(editMode)
         button->timeOut = timeOut;
 
