@@ -1171,7 +1171,7 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         }
     file.close();
 
-    QDir dir("/home/user/MyDocs/qtirreco/themes/");
+    QDir dir(themesPath);
     for(int i=0;i<themesForRemote.length();i++) {
         if(dir.exists(themesForRemote.at(i))) {
             themesForRemote.removeAt(i);
@@ -1373,10 +1373,10 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         QVariant folder = array.value("folder");
 
         QDir dir;
-        dir.mkpath("/home/user/MyDocs/qtirreco/themes/"+themeFolder+"/buttons/"+folder.toString().toLower());
-        buttonPath = QString("/home/user/MyDocs/qtirreco/themes/"+themeFolder+"/buttons/"+folder.toString().toLower());
+        dir.mkpath(themesPath + themeFolder + "/buttons/" + folder.toString().toLower());
+        buttonPath = QString(themesPath + themeFolder + "/buttons/" + folder.toString().toLower());
         if(themeButtonIndex == 1) {
-            QFile themeConf("/home/user/MyDocs/qtirreco/themes/"+themeFolder+"/theme.conf");
+            QFile themeConf(themesPath + themeFolder + "/theme.conf");
             if (!themeConf.open(QIODevice::ReadWrite | QIODevice::Text))
             return;
             QTextStream in(&themeConf);
@@ -1449,8 +1449,8 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         QVariant folder = array.value("folder");
 
         QDir dir;
-        dir.mkpath("/home/user/MyDocs/qtirreco/themes/"+themeFolder+"/bg/"+folder.toString());
-        bgPath = QString("/home/user/MyDocs/qtirreco/themes/"+themeFolder+"/bg/"+folder.toString());
+        dir.mkpath(themesPath + themeFolder + "/bg/" + folder.toString());
+        bgPath = QString(themesPath + themeFolder + "/bg/" + folder.toString());
         QFile bgConf(bgPath+"/bg.conf");
         if (!bgConf.open(QIODevice::ReadWrite | QIODevice::Text))
         return;
