@@ -16,14 +16,15 @@
 #include "uploaddbdlg.h"
 #include "downloaduserremotedlg.h"
 #include "qxtxmlrpcclient.h"
+#include "definitions.h"
+
+
 
-#define DEVICECONF "/home/user/MyDocs/qtirreco/Remotes/remotes.conf"
-#define DEVICEREMOTES "/home/user/MyDocs/qtirreco/Remotes/"
-#define DEVICEDEFAULTIMAGE "/home/user/.qtirreco/themes/default/bg/qtirreco/irreco_logo.png"
-#define DEVICES "/home/user/MyDocs/qtirreco/Devices/"
 
 class LayoutWidget;
 
+
+
 namespace Ui
 {
     class QtIrrecoClass;
@@ -74,6 +75,7 @@ private:
     QPushButton *upDBButton;
     QPushButton *downDBButton;
     QPushButton *dataBaseButton;
+    QPushButton *snapButton;
     //! Boolean to tell if use mode enabled or disabled.
     bool useModeEnabled;
     //! Boolean to tell if menu buttons visible.
@@ -159,7 +161,6 @@ private:
     int themeButtonIndex;
 
     QStringList *remoteNames;
-    QString backgroundMode;
     //! RGB values in string format.
     QString red,green,blue;
     //! List of lirc files.
@@ -189,8 +190,8 @@ private:
     QProgressBar *progress;
     //! Value for progress bar.
     int progressValue;
-
-
+    //! Enum for background mode.
+    backgroundModes backgroundMode;
 
 
 
@@ -213,7 +214,6 @@ private slots:
     void changeRemote();
     void changeNewRemoteName(QString newName);
     void createRemote(QString newRemoteName);
-    void showSaveError();
     void deleteActiveRemote();
     void addRemoteName(QString newRemoteName);
     void downloadDB();
@@ -223,11 +223,12 @@ private slots:
     void error(int i,QString string);
     void fault(int i,int j,QString string);
     void showDBButtons();
+    void snapToGrid();
 
 
 public slots:
     void AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number);
-      void AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number, int timeOut);
+    void AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number, int timeOut);
 
 signals:
     void remoteNameToLw(QString remoteName);
