@@ -44,7 +44,14 @@ void RegisterDlg::changeEvent(QEvent *e)
 
 void RegisterDlg::on_registerPushButton_clicked()
 {
-    if(m_ui->lineEdit_3->text() == m_ui->lineEdit_4->text()) {
+    // TÄHÄN PITÄÄ KEKSIÄ JOKU JÄRKEVÄ KEINO!!!!
+    if(m_ui->lineEdit->text().contains("/", Qt::CaseInsensitive) || m_ui->lineEdit->text().contains("'", Qt::CaseInsensitive)  ||
+    m_ui->lineEdit->text().contains("*", Qt::CaseInsensitive) || m_ui->lineEdit->text().contains(" ", Qt::CaseInsensitive) ) {
+        QMessageBox::warning(this,"Username error ","Username cannot contain special letters like / * or space.",
+                     QMessageBox::NoButton,QMessageBox::NoButton);
+        return;
+    }
+    else if(m_ui->lineEdit_3->text() == m_ui->lineEdit_4->text()) {
         QByteArray hasharray(QCryptographicHash::hash(m_ui->lineEdit_4->text().toUtf8(),QCryptographicHash::Sha1));
         hasharray = hasharray.toHex();
         QString hashpwd(hasharray);
@@ -65,6 +72,7 @@ void RegisterDlg::on_registerPushButton_clicked()
         m_ui->lineEdit_4->clear();
     }
 
+
 }
 void RegisterDlg::allowRegister()
 {
