@@ -85,7 +85,7 @@ void RemoteStartupDlg::loadRemote()
 {
     m_ui->remoteNameLineEdit->setText(remoteName);
 
-    QFile file("/home/user/MyDocs/qtirreco/Devices/" + remoteName);
+    QFile file(devicesPath + remoteName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     return;
 
@@ -112,6 +112,7 @@ void RemoteStartupDlg::removeFromSelectedList(QListWidgetItem* item)
      m_ui->buttonlistWidget->insertItem(buttonsCount, item->text());
      m_ui->buttonlistWidget->sortItems(Qt::AscendingOrder);
      delete m_ui->addedButtonslistWidget->currentItem();
+     addedButtonsCount--;
      buttonsCount = m_ui->buttonlistWidget->count();
 }
 
