@@ -280,18 +280,18 @@ void ThemeCreatorDlg::on_saveThemePushButton_clicked()
             theme.remove(i,1);
     }
     QDir dir;
-    if(!dir.exists("/home/user/MyDocs/qtirreco/themes/" + theme)) {
-        dir.mkpath("/home/user/MyDocs/qtirreco/themes/" + theme);
-        dir.mkdir("/home/user/MyDocs/qtirreco/themes/" + theme + "/bg");
-        dir.mkdir("/home/user/MyDocs/qtirreco/themes/" + theme + "/buttons");
+    if(!dir.exists(themesPath + theme)) {
+        dir.mkpath(themesPath + theme);
+        dir.mkdir(themesPath + theme + "/bg");
+        dir.mkdir(themesPath + theme + "/buttons");
         for(int i=0;i<backgrounds->count();i++) {
            // Copy background images to proper path
-           dir.mkdir("/home/user/MyDocs/qtirreco/themes/" + theme + "/bg/" + backgrounds->at(i)->name.toLower());
+           dir.mkdir(themesPath + theme + "/bg/" + backgrounds->at(i)->name.toLower());
            QFile bgFile(backgrounds->at(i)->picturePath);
-           bgFile.copy("/home/user/MyDocs/qtirreco/themes/" + theme + "/bg/" + backgrounds->at(i)->name.toLower() + "/image.png");
+           bgFile.copy(themesPath + theme + "/bg/" + backgrounds->at(i)->name.toLower() + "/image.png");
            bgFile.close();
            // bg.conf files
-           QFile bgConf("/home/user/MyDocs/qtirreco/themes/" + theme + "/bg/" + backgrounds->at(i)->name.toLower() + "/bg.conf");
+           QFile bgConf(themesPath + theme + "/bg/" + backgrounds->at(i)->name.toLower() + "/bg.conf");
            if (!bgConf.open(QIODevice::ReadWrite | QIODevice::Text))
            return;
            QTextStream in(&bgConf);
@@ -302,15 +302,15 @@ void ThemeCreatorDlg::on_saveThemePushButton_clicked()
         }
         for(int i=0;i<buttons->count();i++) {
            // Copy button images to proper path
-           dir.mkdir("/home/user/MyDocs/qtirreco/themes/" + theme + "/buttons/" + buttons->at(i)->buttonName.toLower());
+           dir.mkdir(themesPath + theme + "/buttons/" + buttons->at(i)->buttonName.toLower());
            QFile upFile(buttons->at(i)->unpressedPath);
            QFile downFile(buttons->at(i)->pressedPath);
-           upFile.copy("/home/user/MyDocs/qtirreco/themes/" + theme + "/buttons/" + buttons->at(i)->buttonName.toLower() +"/unpressed.png");
-           downFile.copy("/home/user/MyDocs/qtirreco/themes/" + theme + "/buttons/" + buttons->at(i)->buttonName.toLower() +"/pressed.png");
+           upFile.copy(themesPath + theme + "/buttons/" + buttons->at(i)->buttonName.toLower() +"/unpressed.png");
+           downFile.copy(themesPath + theme + "/buttons/" + buttons->at(i)->buttonName.toLower() +"/pressed.png");
            upFile.close();
            downFile.close();
            // button.conf files
-           QFile buttonConf("/home/user/MyDocs/qtirreco/themes/" + theme + "/buttons/" + buttons->at(i)->buttonName.toLower() + "/button.conf");
+           QFile buttonConf(themesPath + theme + "/buttons/" + buttons->at(i)->buttonName.toLower() + "/button.conf");
            if (!buttonConf.open(QIODevice::ReadWrite | QIODevice::Text))
            return;
            QTextStream in(&buttonConf);
@@ -364,7 +364,7 @@ void ThemeCreatorDlg::on_saveThemePushButton_clicked()
               }
         }
         // theme.conf file
-        QFile themeConf("/home/user/MyDocs/qtirreco/themes/" + theme + "/theme.conf");
+        QFile themeConf(themesPath + theme + "/theme.conf");
         if (!themeConf.open(QIODevice::ReadWrite | QIODevice::Text))
         return;
         QTextStream in(&themeConf);
