@@ -41,9 +41,6 @@ ThemeManager::ThemeManager(QWidget *parent) :
     progressItemCount = 0;
     uploadItemsCount = 0;
     deviceThemeCount = 0;
-
-    //! PATH FOR DEVICE /home/user/MyDocs/qtirreco//home/user/MyDocs/qtirreco/themes/
-    //! PATH FOR EMULATOR themes/
 }
 
 ThemeManager::~ThemeManager()
@@ -253,7 +250,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
             dbThemeDateList.clear();
         }
 
-        this->getThemeVersionIdsByName(m_ui->nameLabel->text());
+        this->getThemeVersionIds();
         themeVersionIndex++;
     }
     if (Id == themePreviewImage)
@@ -689,7 +686,7 @@ void ThemeManager::getThemeNamesByIds()
         this->setWindowTitle("Themes available on database");
     }
 }
-void ThemeManager::getThemeVersionIdsByName(QString themeName)
+void ThemeManager::getThemeVersionIds()
 {
      if(themeVersionIndex < dbThemeVersionIdList.count())
         {
@@ -988,7 +985,7 @@ void ThemeManager::deleteTheme(QString delThemeName)
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/themes/" + delThemeName);
+    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/.themes/" + delThemeName);
     system(delCommand.toAscii().data());
 }
 void ThemeManager::deleteTheme()
@@ -1027,7 +1024,7 @@ void ThemeManager::deleteTheme()
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/themes/" + themeToDelete);
+    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/.themes/" + themeToDelete);
     system(delCommand.toAscii().data());
     QDir themeDir(themesPath + themeToDelete);
     if(!themeDir.exists())
@@ -1090,7 +1087,7 @@ void ThemeManager::replaceTheme()
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/themes/" + themeToDelete);
+    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/.themes/" + themeToDelete);
     system(delCommand.toAscii().data());
 
     QDir themeDir(themesPath + themeToDelete);
